==> touhoulittlemaid-fabric-1.20.1-0.1.0-forge1.3.7-sources.jar: com/github/tartaricacid/touhoulittlemaid/tileentity/TileEntityMaidBed.java <==
package com.github.tartaricacid.touhoulittlemaid.tileentity;

import cn.sh1rocu.touhoulittlemaid.api.extension.IBlockEntityPersistentData;
import com.github.tartaricacid.touhoulittlemaid.init.InitBlocks;
import javax.annotation.Nullable;
import net.minecraft.class_1767;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_2487;
import net.minecraft.class_2586;
import net.minecraft.class_2591;
import net.minecraft.class_2596;
import net.minecraft.class_2602;
import net.minecraft.class_2622;
import net.minecraft.class_2680;

public class TileEntityMaidBed extends class_2586 implements IBlockEntityPersistentData {
    public static final class_2591<TileEntityMaidBed> TYPE = class_2591.class_2592.method_20528(TileEntityMaidBed::new, InitBlocks.MAID_BED).method_11034(null);
    private static final String COLOR_TAG = "BedColor";
    private class_1767 color = class_1767.field_7954;

    public TileEntityMaidBed(class_2338 blockPos, class_2680 blockState) {
        super(TYPE, blockPos, blockState);
    }

    public void setColor(class_1767 color) {
        this.color = color;
        this.refresh();
    }

    @Override
    public void method_11007(class_2487 compound) {
        getPersistentData().method_10569(COLOR_TAG, color.method_7789());
        super.method_11007(compound);
    }

    @Override
    public void method_11014(class_2487 nbt) {
        super.method_11014(nbt);
        color = class_1767.method_7791(getPersistentData().method_10550(COLOR_TAG));
    }

    @Override
    public class_2487 method_16887() {
        return this.method_38244();
    }

    @Nullable
    @Override
    public class_2596<class_2602> method_38235() {
        return class_2622.method_38585(this);
    }

    public void refresh() {
        this.method_5431();
        if (field_11863 != null) {
            class_2680 state = field_11863.method_8320(field_11867);
            field_11863.method_8413(field_11867, state, state, class_2248.field_31036);
        }
    }

    public class_1767 getColor() {
        return color;
    }

//    @Override
//    @Environment(EnvType.CLIENT)
//    public AABB getRenderBoundingBox() {
//        return new AABB(worldPosition.offset(-2, 0, -2), worldPosition.offset(2, 1, 2));
//    }
}

==> touhoulittlemaid-fabric-1.20.1-0.2.0-forge1.4.2-sources.jar: com/github/tartaricacid/touhoulittlemaid/tileentity/TileEntityMaidBed.java <==
package com.github.tartaricacid.touhoulittlemaid.tileentity;

import cn.sh1rocu.touhoulittlemaid.api.extension.IBlockEntityPersistentData;
import com.github.tartaricacid.touhoulittlemaid.init.InitBlocks;
import javax.annotation.Nullable;
import net.minecraft.class_1767;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_2487;
import net.minecraft.class_2586;
import net.minecraft.class_2591;
import net.minecraft.class_2596;
import net.minecraft.class_2602;
import net.minecraft.class_2622;
import net.minecraft.class_2680;

public class TileEntityMaidBed extends class_2586 implements IBlockEntityPersistentData {
    public static final class_2591<TileEntityMaidBed> TYPE = class_2591.class_2592.method_20528(TileEntityMaidBed::new, InitBlocks.MAID_BED).method_11034(null);
    private static final String COLOR_TAG = "BedColor";
    private class_1767 color = class_1767.field_7954;

    public TileEntityMaidBed(class_2338 blockPos, class_2680 blockState) {
        super(TYPE, blockPos, blockState);
    }

    public void setColor(class_1767 color) {
        this.color = color;
        this.refresh();
    }

    @Override
    public void method_11007(class_2487 compound) {
        tlm$getPersistentData().method_10569(COLOR_TAG, color.method_7789());
        super.method_11007(compound);
    }

    @Override
    public void method_11014(class_2487 nbt) {
        super.method_11014(nbt);
        color = class_1767.method_7791(tlm$getPersistentData().method_10550(COLOR_TAG));
    }

    @Override
    public class_2487 method_16887() {
        return this.method_38244();
    }

    @Nullable
    @Override
    public class_2596<class_2602> method_38235() {
        return class_2622.method_38585(this);
    }

    public void refresh() {
        this.method_5431();
        if (field_11863 != null) {
            class_2680 state = field_11863.method_8320(field_11867);
            field_11863.method_8413(field_11867, state, state, class_2248.field_31036);
        }
    }

    public class_1767 getColor() {
        return color;
    }

//    @Override
//    @Environment(EnvType.CLIENT)
//    public AABB getRenderBoundingBox() {
//        return new AABB(worldPosition.offset(-2, 0, -2), worldPosition.offset(2, 1, 2));
//    }
}
